@@ -138,7 +138,7 @@ module FFI
     #   ffi_lib_flags(:lazy, :local) # => 5
     #
     # @param [Symbol, …] flags (see {FlagsMap})
-    # @return [Fixnum] the new value
+    # @return [Integer] the new value
     def ffi_lib_flags(*flags)
       @ffi_lib_flags = flags.inject(0) { |result, f| result | FlagsMap[f] }
     end
@@ -398,6 +398,26 @@ module FFI
       end
     end
 
+    # @param [DataConverter, Type, Struct, Symbol] t type to find
+    # @return [Type]
+    # Find a type definition.
+    def find_type(t)
+      if t.kind_of?(Type)
+        t
+
+      elsif defined?(@ffi_typedefs) && @ffi_typedefs.has_key?(t)
+        @ffi_typedefs[t]
+
+      elsif t.is_a?(Class) && t < Struct
+        Type::POINTER
+
+      elsif t.is_a?(DataConverter)
+        # Add a typedef so next time the converter is used, it hits the cache
+        typedef Type::Mapped.new(t), t
+
+      end || FFI.find_type(t)
+    end
+
     private
     # Generic enum builder
     #  @param [Class] klass can be one of FFI::Enum or FFI::Bitmask
@@ -518,26 +538,6 @@ module FFI
       @ffi_enums.__map_symbol(symbol)
     end
 
-    # @param [DataConverter, Type, Struct, Symbol] t type to find
-    # @return [Type]
-    # Find a type definition.
-    def find_type(t)
-      if t.kind_of?(Type)
-        t
-
-      elsif defined?(@ffi_typedefs) && @ffi_typedefs.has_key?(t)
-        @ffi_typedefs[t]
-
-      elsif t.is_a?(Class) && t < Struct
-        Type::POINTER
-
-      elsif t.is_a?(DataConverter)
-        # Add a typedef so next time the converter is used, it hits the cache
-        typedef Type::Mapped.new(t), t
-
-      end || FFI.find_type(t)
-    end
-
     # Retrieve all attached functions and their function signature
     #
     # This method returns a Hash of method names of attached functions connected by #attach_function and the corresponding function type.
@@ -555,10 +555,10 @@ module FFI
     # @return [Hash< Symbol => ffi_type >]
     def attached_variables
       (
-        (@ffi_gsvars || {}).map do |name, gvar|
+        (defined?(@ffi_gsvars) ? @ffi_gsvars : {}).map do |name, gvar|
           [name, gvar.class]
         end +
-        (@ffi_gvars || {}).map do |name, gvar|
+        (defined?(@ffi_gvars) ? @ffi_gvars : {}).map do |name, gvar|
           [name, gvar.layout[:gvar].type]
         end
       ).to_h
